pub struct MobEffectBehaviorRegistry {
behaviors: Vec<Box<dyn MobEffectBehavior>>,
}Expand description
Registry for mob-effect behaviors.
Created after the main registry is frozen. All mob effects are
initialized with a default behavior matching a bare vanilla MobEffect
instance, then custom behaviors are registered.
Fields
behaviors: Vec<Box<dyn MobEffectBehavior>>Implementations
Sourceimpl MobEffectBehaviorRegistry
impl MobEffectBehaviorRegistry
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new behavior registry with default behaviors for all mob effects.
Sourcepub fn set_behavior(
&mut self,
effect: MobEffectRef,
behavior: Box<dyn MobEffectBehavior>,
)
pub fn set_behavior( &mut self, effect: MobEffectRef, behavior: Box<dyn MobEffectBehavior>, )
Sets a custom behavior for a mob effect.
Panics
Panics if effect is not registered in the global registry.
Sourcepub fn get_behavior(&self, effect: MobEffectRef) -> &dyn MobEffectBehavior
pub fn get_behavior(&self, effect: MobEffectRef) -> &dyn MobEffectBehavior
Gets the behavior for a mob effect.
Panics
Panics if effect is not registered in the global registry.